//
//  ViewController.swift
//  Record
//
//  Created by Neil Smyth on 11/9/14.
//  Copyright (c) 2014 Neil Smyth. All rights reserved.
//

import UIKit
import AVFoundation

class ViewController: UIViewController, AVAudioPlayerDelegate, AVAudioRecorderDelegate {

    var audioPlayer: AVAudioPlayer?
    var audioRecorder: AVAudioRecorder?

    @IBOutlet weak var recordButton: UIButton!
    @IBOutlet weak var stopButton: UIButton!
    @IBOutlet weak var playButton: UIButton!
    
    override func viewDidLoad() {
        super.viewDidLoad()
        playButton.enabled = false
        stopButton.enabled = false

        let dirPaths = 
        NSSearchPathForDirectoriesInDomains(.DocumentDirectory,
                            .UserDomainMask, true)
        let docsDir = dirPaths[0] as! String
        let soundFilePath = 
            docsDir.stringByAppendingPathComponent("sound.caf")
        let soundFileURL = NSURL(fileURLWithPath: soundFilePath)
        let recordSettings = 
            [AVEncoderAudioQualityKey: AVAudioQuality.Min.rawValue,
                    AVEncoderBitRateKey: 16,
                    AVNumberOfChannelsKey: 2,
                    AVSampleRateKey: 44100.0]

        var error: NSError?

        let audioSession = AVAudioSession.sharedInstance()
        audioSession.setCategory(AVAudioSessionCategoryPlayAndRecord, 
                            error: &error)

        if let err = error {
            println("audioSession error: \(err.localizedDescription)")
        }

        audioRecorder = AVAudioRecorder(URL: soundFileURL, 
                    settings: recordSettings as [NSObject : AnyObject], error: &error)

        if let err = error {
            println("audioSession error: \(err.localizedDescription)")
        } else {
            audioRecorder?.prepareToRecord()
        }

    }

    @IBAction func recordAudio(sender: AnyObject) {
        if audioRecorder?.recording == false {
            playButton.enabled = false
            stopButton.enabled = true
            audioRecorder?.record()
        }

    }
    
    @IBAction func stopAudio(sender: AnyObject) {
        stopButton.enabled = false
        playButton.enabled = true
        recordButton.enabled = true

        if audioRecorder?.recording == true {
            audioRecorder?.stop()
        } else {
            audioPlayer?.stop()
        }

    }
    
    @IBAction func playAudio(sender: AnyObject) {
        if audioRecorder?.recording == false {
            stopButton.enabled = true
            recordButton.enabled = false

            var error: NSError?

            audioPlayer = AVAudioPlayer(contentsOfURL: audioRecorder?.url, 
                error: &error)

            audioPlayer?.delegate = self

            if let err = error {
                println("audioPlayer error: \(err.localizedDescription)")
            } else {
                audioPlayer?.play()
            }
        }

    }

    func audioPlayerDidFinishPlaying(player: AVAudioPlayer!, successfully flag: Bool) {
        recordButton.enabled = true
        stopButton.enabled = false
    }

    func audioPlayerDecodeErrorDidOccur(player: AVAudioPlayer!, error: NSError!) {
        println("Audio Play Decode Error")
    }

    func audioRecorderDidFinishRecording(recorder: AVAudioRecorder!, successfully flag: Bool) {
    }

    func audioRecorderEncodeErrorDidOccur(recorder: AVAudioRecorder!, error: NSError!) {
        println("Audio Record Encode Error")
    }

    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }


}

