//
//  SecondViewController.swift
//  ReminderApp
//
//  Created by Neil Smyth on 11/9/14.
//  Copyright (c) 2014 Neil Smyth. All rights reserved.
//

import UIKit
import EventKit
import CoreLocation

class SecondViewController: UIViewController, CLLocationManagerDelegate  {

    @IBOutlet weak var locationText: UITextField!
    var appDelegate: AppDelegate?
    var locationManager: CLLocationManager = CLLocationManager()
    
    override func viewDidLoad() {
        super.viewDidLoad()
        // Do any additional setup after loading the view, typically from a nib.
        locationManager.requestWhenInUseAuthorization()
        locationManager.delegate = self
        locationManager.distanceFilter = kCLDistanceFilterNone
        locationManager.desiredAccuracy = kCLLocationAccuracyBest
    }

    @IBAction func setLocationReminder(sender: AnyObject) {

        appDelegate = UIApplication.sharedApplication().delegate as? AppDelegate

        if appDelegate!.eventStore == nil {
            appDelegate!.eventStore = EKEventStore()
            appDelegate!.eventStore?.requestAccessToEntityType(
          EKEntityTypeReminder, completion: 
            {(granted: Bool, error:NSError!) in
                if !granted {
                    println("Access to store not granted")
                } else {
                    println("Access granted")
                }
            })
        }

        if (appDelegate!.eventStore != nil) {

            locationManager.startUpdatingLocation()
        }

    }

    func locationManager(manager: CLLocationManager!, didUpdateLocations locations: [AnyObject]!) {
 
        locationManager.stopUpdatingLocation()

        let reminder = EKReminder(eventStore: appDelegate!.eventStore)
        reminder.title = locationText.text
        reminder.calendar = 
             appDelegate!.eventStore!.defaultCalendarForNewReminders()

        let location = EKStructuredLocation(title: "Current Location")
        location.geoLocation = locations.last as! CLLocation

        let alarm = EKAlarm()

        alarm.structuredLocation = location
        alarm.proximity = EKAlarmProximityLeave

        reminder.addAlarm(alarm)

        var error: NSError?

        appDelegate!.eventStore?.saveReminder(reminder, 
        commit: true, error: &error)

        if error != nil {
            println("Reminder failed with error \(error?.localizedDescription)")
        }
}

    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }


}

